==> lapisworks-1.5.6.7-sources.jar: com/luxof/lapisworks/interop/hexical/Lapixical.java <==
package com.luxof.lapisworks.interop.hexical;

import com.google.common.collect.ImmutableSet;

import com.luxof.lapisworks.init.ModBlocks;
import com.luxof.lapisworks.init.ModItems;
import com.luxof.lapisworks.interop.hexical.blocks.Cradle;
import com.luxof.lapisworks.interop.hexical.blocks.CradleEntity;
import com.luxof.lapisworks.interop.hexical.blocks.Rod;

import static com.luxof.lapisworks.Lapisworks.LOGGER;
import static com.luxof.lapisworks.Lapisworks.verDifference;

import net.fabricmc.fabric.api.item.v1.FabricItemSettings;
import net.minecraft.class_1747;
import net.minecraft.class_1792.class_1793;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import vazkii.patchouli.api.PatchouliAPI;

/** uhh, Lapixical and Hexisworks? I dunno Hexical is a weird ass name to work with
 * but I like how Hexisworks looks */
public class Lapixical {
    public static class_1793 fullStack = new FabricItemSettings().method_7889(64);
    public static Rod ROD = new Rod();
    public static Cradle CRADLE = new Cradle();
    public static class_2591<class_2586> CRADLE_ENTITY_TYPE = new class_2591<class_2586>(
        CradleEntity::new,
        ImmutableSet.of(CRADLE),
        null
    );
    public static class_1747 ROD_ITEM = new class_1747(ROD, fullStack);
    public static class_1747 CRADLE_ITEM = new class_1747(CRADLE, fullStack);

    public static void initHexicalInterop() {
        Integer verDiff = verDifference("hexical", "1.5.0");
        if (verDiff == null) {
            LOGGER.error("How in the actual fuck did I cuck up Hexical interop?");
            verDiff = 0;
        }
        if (verDiff > 0) {
            // the only version after hexical 1.5.0 is 2.0.0
            FullLapixical.initHexical200Interop();
        } else {
            PatchouliAPI.get().setConfigFlag("lapisworks:no_fulllapixical", true);
        }
        ModBlocks.pickACropTop("rod", ROD);
        ModBlocks.pickACropTop("cradle", CRADLE);
        ModBlocks.dontForgetStockings("cradle_entity_type", CRADLE_ENTITY_TYPE);
        ModItems.registerItem("rod", ROD_ITEM);
        ModItems.registerItem("cradle", CRADLE_ITEM);
    }
}

==> lapisworks-1.5.7-sources.jar: com/luxof/lapisworks/interop/hexical/Lapixical.java <==
package com.luxof.lapisworks.interop.hexical;

import com.google.common.collect.ImmutableSet;

import com.luxof.lapisworks.init.ModBlocks;
import com.luxof.lapisworks.init.ModItems;
import com.luxof.lapisworks.interop.hexical.blocks.Cradle;
import com.luxof.lapisworks.interop.hexical.blocks.CradleEntity;
import com.luxof.lapisworks.interop.hexical.blocks.Rod;

import static com.luxof.lapisworks.Lapisworks.LOGGER;
import static com.luxof.lapisworks.Lapisworks.verDifference;

import net.fabricmc.fabric.api.item.v1.FabricItemSettings;
import net.minecraft.class_1747;
import net.minecraft.class_1792.class_1793;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import vazkii.patchouli.api.PatchouliAPI;

/** uhh, Lapixical and Hexisworks? I dunno Hexical is a weird ass name to work with
 * but I like how Hexisworks looks */
public class Lapixical {
    public static class_1793 fullStack = new FabricItemSettings().method_7889(64);
    public static Rod ROD = new Rod();
    public static Cradle CRADLE = new Cradle();
    public static class_2591<class_2586> CRADLE_ENTITY_TYPE = new class_2591<class_2586>(
        CradleEntity::new,
        ImmutableSet.of(CRADLE),
        null
    );
    public static class_1747 ROD_ITEM = new class_1747(ROD, fullStack);
    public static class_1747 CRADLE_ITEM = new class_1747(CRADLE, fullStack);

    public static void initHexicalInterop() {
        Integer verDiff = verDifference("hexical", "1.5.0");
        if (verDiff == null) {
            LOGGER.error("How in the actual fuck did I cuck up Hexical interop?");
            verDiff = 0;
        }
        if (verDiff > 0) {
            // the only version after hexical 1.5.0 is 2.0.0
            FullLapixical.initHexical200Interop();
        } else {
            PatchouliAPI.get().setConfigFlag("lapisworks:fulllapixical", false);
        }
        ModBlocks.pickACropTop("rod", ROD);
        ModBlocks.pickACropTop("cradle", CRADLE);
        ModBlocks.dontForgetStockings("cradle_entity_type", CRADLE_ENTITY_TYPE);
        ModItems.registerItem("rod", ROD_ITEM);
        ModItems.registerItem("cradle", CRADLE_ITEM);
    }
}
